local TEXTURE = Resources.load_texture("scalepowder.png")

function card_init(player, props)
	local tile = player:get_tile(player:facing(), 1)
	local action = Action.new(player, "CHARACTER_SHOOT")
	action.on_execute_func = function(self, user)
		local buster = self:create_attachment("BUSTER")
		local buster_sprite = buster:sprite()
		buster_sprite:set_texture(user:texture())
		buster_sprite:set_layer(-2)
		buster_sprite:use_root_shader(true)

		local buster_anim = buster:animation()
		buster_anim:copy_from(user:animation())
		buster_anim:set_state("BUSTER")
		self:add_anim_action(2, function()
			local spell = create_powder(player, props)
			player:field():spawn(spell, tile)
		end)
	end
	return action
end

function create_powder(user, props)
	local spell = Spell.new(user:team())
	local direction = user:facing()
	spell:set_tile_highlight(Highlight.Solid)
	spell:set_facing(direction)
	spell:set_hit_props(
		HitProps.new(
			props.damage,
			props.hit_flags,
			props.element,
			user:context(),
			Drag.None
		)
	)
	spell:set_texture(TEXTURE, true)
	local fx_anim = spell:animation()
	fx_anim:load("powder.animation")
	fx_anim:set_state("DEFAULT")
	fx_anim:set_playback(Playback.Loop)

	local teleport_cooldown = 12
	spell.on_update_func = function(self)
		spell:current_tile():attack_entities(self)
		if spell:current_tile():is_edge() then
			spell:delete()
		end
		if teleport_cooldown <= 0 and not self:is_teleporting() then
			self:teleport(self:get_tile(self:facing(), 1), function() end)
			teleport_cooldown = 12
		else
			teleport_cooldown = teleport_cooldown - 1
		end
	end

	spell.on_collision_func = function(self, other)
		self:delete()
	end

	spell.on_delete_func = function(self)
		self:erase()
	end

	spell.can_move_to_func = function(self, tile)
		return true
	end

	return spell
end
